@@ -48,16 +48,20 @@ module("selector", { teardown: moduleTeardown });
 test("element", function() {
 	expect( 37 );
 
+	var form, all, good, i, obj1, lengthtest,
+		siblingTest, iframe, iframeDoc, html;
+
 	equal( Sizzle("").length, 0, "Empty selector returns an empty array" );
 	equal( Sizzle(" ").length, 0, "Empty selector returns an empty array" );
 	equal( Sizzle("\t").length, 0, "Empty selector returns an empty array" );
-	var form = document.getElementById("form");
+	form = document.getElementById("form");
 	ok( !Sizzle.matchesSelector( form, "" ), "Empty string passed to matchesSelector does not match" );
 
 	ok( Sizzle("*").length >= 30, "Select all" );
-	var all = Sizzle("*"), good = true;
-	for ( var i = 0; i < all.length; i++ ) {
-		if ( all[i].nodeType == 8 ) {
+	all = Sizzle("*");
+	good = true;
+	for ( i = 0; i < all.length; i++ ) {
+		if ( all[i].nodeType === 8 ) {
 			good = false;
 		}
 	}
@@ -79,7 +83,7 @@ test("element", function() {
 
 	t( "Parent Element", "dl ol", ["empty", "listWithTabIndex"] );
 	t( "Parent Element (non-space descendant combinator)", "dl\tol", ["empty", "listWithTabIndex"] );
-	var obj1 = document.getElementById("object1");
+	obj1 = document.getElementById("object1");
 	equal( Sizzle("param", obj1).length, 2, "Object/param as context" );
 
 	deepEqual( Sizzle("select", form), q("select1","select2","select3","select4","select5"), "Finding selects with a context." );
@@ -92,17 +96,17 @@ test("element", function() {
 	t( "Checking sort order", "#qunit-fixture p, #qunit-fixture p a", ["firstp", "simon1", "ap", "google", "groups", "anchor1", "mark", "sndp", "en", "yahoo", "sap", "anchor2", "simon", "first"] );
 
 	// Test Conflict ID
-	var lengthtest = document.getElementById("lengthtest");
+	lengthtest = document.getElementById("lengthtest");
 	deepEqual( Sizzle("#idTest", lengthtest), q("idTest"), "Finding element with id of ID." );
 	deepEqual( Sizzle("[name='id']", lengthtest), q("idTest"), "Finding element with id of ID." );
 	deepEqual( Sizzle("input[id='idTest']", lengthtest), q("idTest"), "Finding elements with id of ID." );
 
-	var siblingTest = document.getElementById("siblingTest");
+	siblingTest = document.getElementById("siblingTest");
 	deepEqual( Sizzle("div em", siblingTest), [], "Element-rooted QSA does not select based on document context" );
 	deepEqual( Sizzle("div em, div em, div em:not(div em)", siblingTest), [], "Element-rooted QSA does not select based on document context" );
 	deepEqual( Sizzle("div em, em\\,", siblingTest), [], "Escaped commas do not get treated with an id in element-rooted QSA" );
 
-	var iframe = document.getElementById("iframe"),
+	iframe = document.getElementById("iframe"),
 		iframeDoc = iframe.contentDocument || iframe.contentWindow.document;
 	iframeDoc.open();
 	iframeDoc.write("<body><p id='foo'>bar</p></body>");
@@ -113,7 +117,7 @@ test("element", function() {
 		"Other document as context"
 	);
 
-	var html = "";
+	html = "";
 	for ( i = 0; i < 100; i++ ) {
 		html = "<div>" + html + "</div>";
 	}
@@ -201,7 +205,9 @@ test("broken", function() {
 });
 
 test("id", function() {
-	expect( 31 );
+	expect( 32 );
+
+	var fiddle, a;
 
 	t( "ID Selector", "#body", ["body"] );
 	t( "ID Selector w/ Element", "body#body", ["body"] );
@@ -221,7 +227,7 @@ test("id", function() {
 	t( "Child escaped ID", "form > #foo\\:bar", ["foo:bar"] );
 	t( "Child escaped ID", "form > #test\\.foo\\[5\\]bar", ["test.foo[5]bar"] );
 
-	var fiddle = jQuery("<div id='fiddle\\Foo'><span id='fiddleSpan'></span></div>").appendTo("#qunit-fixture");
+	fiddle = jQuery("<div id='fiddle\\Foo'><span id='fiddleSpan'></span></div>").appendTo("#qunit-fixture");
 	deepEqual( Sizzle( "> span", Sizzle("#fiddle\\\\Foo")[0] ), q([ "fiddleSpan" ]), "Escaped ID as context" );
 	fiddle.remove();
 
@@ -232,9 +238,14 @@ test("id", function() {
 	t( "All Children of ID", "#foo > *", ["sndp", "en", "sap"] );
 	t( "All Children of ID with no children", "#firstUL > *", [] );
 
-	var a = jQuery("<div><a name=\"tName1\">tName1 A</a><a name=\"tName2\">tName2 A</a><div id=\"tName1\">tName1 Div</div></div>").appendTo("#qunit-fixture");
+	a = jQuery("<div>" +
+		"<a name='tName1'>tName1 <code>A</code></a>" +
+		"<a name='tName2'>tName2 <code>A</code></a>" +
+		"<div id='tName1'>tName1 <code>DIV</code></div>" +
+	"</div>").appendTo("#qunit-fixture");
 	equal( Sizzle("#tName1")[0].id, "tName1", "ID selector with same value for a name attribute" );
-	equal( Sizzle("#tName2").length, 0, "ID selector non-existing but name attribute on an A tag" );
+	deepEqual( Sizzle("#tName2"), [], "ID selector non-existing but name attribute on an A tag" );
+	deepEqual( Sizzle("#tName2 code"), [], "Leading ID selector non-existing but name attribute on an A tag" );
 	a.remove();
 
 	a = jQuery("<a id='backslash\\foo'></a>").appendTo("#qunit-fixture");
@@ -253,7 +264,7 @@ test("id", function() {
 });
 
 test("class", function() {
-	expect( 25 );
+	expect( 26 );
 
 	t( "Class Selector", ".blog", ["mark","simon"] );
 	t( "Class Selector", ".GROUPS", ["groups"] );
@@ -293,11 +304,16 @@ test("class", function() {
 
 	div.lastChild.className += " hasOwnProperty toString";
 	deepEqual( Sizzle(".e.hasOwnProperty.toString", div), [ div.lastChild ], "Classes match Object.prototype properties" );
+
+	div = jQuery("<div><svg width='200' height='250' version='1.1' xmlns='http://www.w3.org/2000/svg'><rect x='10' y='10' width='30' height='30' class='foo'></rect></svg></div>")[0];
+	equal( Sizzle(".foo", div).length, 1, "Class selector against SVG" );
 });
 
 test("name", function() {
 	expect( 15 );
 
+	var form, a;
+
 	t( "Name selector", "input[name=action]", ["text1"] );
 	t( "Name selector with single quotes", "input[name='action']", ["text1"] );
 	t( "Name selector with double quotes", "input[name=\"action\"]", ["text1"] );
@@ -308,7 +324,7 @@ test("name", function() {
 
 	t( "Name selector for grouped input", "input[name='types[]']", ["types_all", "types_anime", "types_movie"] );
 
-	var form = document.getElementById("form");
+	form = document.getElementById("form");
 	deepEqual( Sizzle("input[name=action]", form), q("text1"), "Name selector within the context of another element" );
 	deepEqual( Sizzle("input[name='foo[bar]']", form), q("hidden2"), "Name selector for grouped form element within the context of another element" );
 
@@ -317,7 +333,7 @@ test("name", function() {
 
 	form.remove();
 
-	var a = jQuery("<div><a id=\"tName1ID\" name=\"tName1\">tName1 A</a><a id=\"tName2ID\" name=\"tName2\">tName2 A</a><div id=\"tName1\">tName1 Div</div></div>")
+	a = jQuery("<div><a id=\"tName1ID\" name=\"tName1\">tName1 A</a><a id=\"tName2ID\" name=\"tName2\">tName2 A</a><div id=\"tName1\">tName1 Div</div></div>")
 		.appendTo("#qunit-fixture").children();
 
 	equal( a.length, 3, "Make sure the right number of elements were inserted." );
@@ -344,6 +360,8 @@ test("multiple", function() {
 test("child and adjacent", function() {
 	expect( 42 );
 
+	var siblingFirst, en, nothiddendiv;
+
 	t( "Child", "p > a", ["simon1","google","groups","mark","yahoo","simon"] );
 	t( "Child", "p> a", ["simon1","google","groups","mark","yahoo","simon"] );
 	t( "Child", "p >a", ["simon1","google","groups","mark","yahoo","simon"] );
@@ -368,13 +386,13 @@ test("child and adjacent", function() {
 	t( "Element Preceded By (multiple)", "#siblingTest em ~ em ~ em ~ span", ["siblingspan"] );
 	t( "Element Preceded By, Containing", "#liveHandlerOrder ~ div em:contains('1')", ["siblingfirst"] );
 
-	var siblingFirst = document.getElementById("siblingfirst");
+	siblingFirst = document.getElementById("siblingfirst");
 
 	deepEqual( Sizzle("~ em", siblingFirst), q("siblingnext", "siblingthird"), "Element Preceded By with a context." );
 	deepEqual( Sizzle("+ em", siblingFirst), q("siblingnext"), "Element Directly Preceded By with a context." );
 	deepEqual( Sizzle("~ em:first", siblingFirst), q("siblingnext"), "Element Preceded By positional with a context." );
 
-	var en = document.getElementById("en");
+	en = document.getElementById("en");
 	deepEqual( Sizzle("+ p, a", en), q("yahoo", "sap"), "Compound selector with context, beginning with sibling test." );
 	deepEqual( Sizzle("a, + p", en), q("yahoo", "sap"), "Compound selector with context, containing sibling test." );
 
@@ -392,7 +410,7 @@ test("child and adjacent", function() {
 
 	t( "No element deep selector", "div.foo > span > a", [] );
 
-	var nothiddendiv = document.getElementById("nothiddendiv");
+	nothiddendiv = document.getElementById("nothiddendiv");
 	deepEqual( Sizzle("> :first", nothiddendiv), q("nothiddendivchild"), "Verify child context positional selector" );
 	deepEqual( Sizzle("> :eq(0)", nothiddendiv), q("nothiddendivchild"), "Verify child context positional selector" );
 	deepEqual( Sizzle("> *:first", nothiddendiv), q("nothiddendivchild"), "Verify child context positional selector" );
@@ -401,7 +419,7 @@ test("child and adjacent", function() {
 });
 
 test("attributes", function() {
-	expect( 69 );
+	expect( 70 );
 
 	var opt, input, attrbad, div;
 
@@ -523,6 +541,7 @@ test("attributes", function() {
 
 	t( "input[type=text]", "#form input[type=text]", ["text1", "text2", "hidden2", "name"] );
 	t( "input[type=search]", "#form input[type=search]", ["search"] );
+	t( "script[src] (jQuery #13777)", "#moretests script[src]", ["script-src"] );
 
 	// #3279
 	div = document.createElement("div");
@@ -673,7 +692,9 @@ test("pseudo - has", function() {
 });
 
 test("pseudo - misc", function() {
-	expect( 41 );
+	expect( 38 );
+
+	var select, tmp, input;
 
 	t( "Headers", ":header", ["qunit-header", "qunit-banner", "qunit-userAgent"] );
 	t( "Headers(case-insensitive)", ":Header", ["qunit-header", "qunit-banner", "qunit-userAgent"] );
@@ -681,7 +702,7 @@ test("pseudo - misc", function() {
 
 	ok( Sizzle("#qunit-fixture :not(:has(:has(*)))").length, "All not grandparents" );
 
-	var select = document.getElementById("select1");
+	select = document.getElementById("select1");
 	ok( Sizzle.matchesSelector( select, ":has(option)" ), "Has Option Matches" );
 
 	t( "Text Contains", "a:contains(Google)", ["google","groups"] );
@@ -693,7 +714,7 @@ test("pseudo - misc", function() {
 	t( "Text Contains", "a:contains((Link))", ["groups"] );
 
 
-	var tmp = document.createElement("div");
+	tmp = document.createElement("div");
 	tmp.id = "tmp_input";
 	document.body.appendChild( tmp );
 
@@ -736,7 +757,7 @@ test("pseudo - misc", function() {
 	document.body.removeChild( tmp );
 
 	// Input focus/active
-	var input = document.createElement("input");
+	input = document.createElement("input");
 	input.type = "text";
 	input.id = "focus-input";
 
@@ -785,19 +806,6 @@ test("pseudo - misc", function() {
 	t( "Multi-pseudo with leading nonexistent id", "#nonexistent:has(*), #ap:has(*)", ["ap"] );
 	t( "Multi-positional with leading nonexistent id", "#nonexistent:gt(0), #ap:lt(1)", ["ap"] );
 
-	Sizzle.selectors.filters.icontains = function( elem, i, match ) {
-		return Sizzle.getText( elem ).toLowerCase().indexOf( (match[3] || "").toLowerCase() ) > -1;
-	};
-	Sizzle.selectors.setFilters.podium = function( elements, argument ) {
-		var count = argument == null || argument === "" ? 3 : +argument;
-		return elements.slice( 0, count );
-	};
-	t( "Backwards-compatible custom pseudos", "a:icontains(THIS BLOG ENTRY)", ["simon1"] );
-	t( "Backwards-compatible custom setFilters", "#form :PODIUM", ["label-for", "text1", "text2"] );
-	t( "Backwards-compatible custom setFilters with argument", "#form input:Podium(1)", ["text1"] );
-	delete Sizzle.selectors.filters.icontains;
-	delete Sizzle.selectors.setFilters.podium;
-
 	t( "Tokenization stressor", "a[class*=blog]:not(:has(*, :contains(!)), :contains(!)), br:contains(]), p:contains(]), :not(:empty):not(:parent)", ["ap", "mark","yahoo","simon"] );
 });
 
@@ -860,7 +868,7 @@ test("pseudo - :not", function() {
 });
 
 test("pseudo - position", function() {
-	expect( 34 );
+	expect( 33 );
 
 	t( "First element", "div:first", ["qunit"] );
 	t( "First element(case-insensitive)", "div:fiRst", ["qunit"] );
@@ -903,13 +911,6 @@ test("pseudo - position", function() {
 	// jQuery #12526
 	var context = jQuery("#qunit-fixture").append("<div id='jquery12526'></div>")[0];
 	deepEqual( Sizzle( ":last", context ), q("jquery12526"), "Post-manipulation positional" );
-	QUnit.reset();
-
-	// Sizzle extension
-	Sizzle.selectors.setFilters["primary"] = Sizzle.selectors.setFilters["first"];
-	t( "Extend Sizzle's POS selectors to rename first to primary", "div:primary", ["qunit"] );
-	// Reset
-	delete Sizzle.selectors.setFilters["primary"];
 });
 
 test("pseudo - form", function() {
@@ -936,12 +937,13 @@ test("pseudo - :target and :root", function() {
 	expect( 2 );
 
 	// Target
-	var $link = jQuery("<a/>").attr({
+	var oldHash,
+	$link = jQuery("<a/>").attr({
 		href: "#",
 		id: "new-link"
 	}).appendTo("#qunit-fixture");
 
-	var oldHash = window.location.hash;
+	oldHash = window.location.hash;
 	window.location.hash = "new-link";
 
 	t( ":target", ":target", ["new-link"] );
